==> haskell-here-1.2.13-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-DuobncbEwJ6GKqxWGy4Ugi
key: here-1.2.13-DuobncbEwJ6GKqxWGy4Ugi
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 27579e133d4e1279f5dcdfa6a7d005f9
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-DuobncbEwJ6GKqxWGy4Ugi
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-KSyqLEmfp1GGOI8OtM3v3S
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             haskell-src-meta-0.8.0.3-KSyqLEmfp1GGOI8OtM3v3S=e778e173769cb8580fcb151410b1e684
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-LT8aJHGu6DEMH84zXurDn
key: here-1.2.13-LT8aJHGu6DEMH84zXurDn
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 9f3cd73aa33feea5fc7524eb1f8c71ab
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-LT8aJHGu6DEMH84zXurDn
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-Lpzcxammfyz4XlC9fHQyQH
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             haskell-src-meta-0.8.0.3-Lpzcxammfyz4XlC9fHQyQH=1e7b8d69e5f656417ee086a9a3aa7509
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
